@@ -4,6 +4,6 @@ class ForgedQueryStringError(BraintreeError):
     """
     Raised when the query string has been forged or tampered with during a transparent redirect.
 
-    See http://www.braintreepaymentsolutions.com/docs/python/general/exceptions#forged_query_string
+    See http://www.braintreepayments.com/docs/python/general/exceptions#forged_query_string
     """
     pass
