@@ -4,6 +4,6 @@ class ServerError(BraintreeError):
     """
     Raised when the gateway raises an error.  Please contant support at support@getbraintree.com.
 
-    See http://www.braintreepaymentsolutions.com/docs/python/general/exceptions#server_error
+    See http://www.braintreepayments.com/docs/python/general/exceptions#server_error
     """
     pass
