@@ -138,6 +138,10 @@ class Transaction(Resource):
         Credit = "credit"
         Sale = "sale"
 
+    @staticmethod
+    def clone_transaction(transaction_id, params):
+        return Configuration.gateway().transaction.clone_transaction(transaction_id, params)
+
     @staticmethod
     def confirm_transparent_redirect(query_string):
         """
@@ -305,6 +309,10 @@ class Transaction(Resource):
         """
         return Configuration.gateway().transaction.create(params)
 
+    @staticmethod
+    def clone_signature():
+        return ["amount", {"options": ["submit_for_settlement"]}]
+
     @staticmethod
     def create_signature():
         return [
